<?php

namespace Drupal\redhen_connection;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the ConnectionRole entity.
 *
 * @see \Drupal\redhen_connection\Entity\ConnectionRole
 */
class ConnectionRoleAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected $viewLabelOperation = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\redhen_connection\ConnectionRoleInterface $entity */

    switch ($operation) {
      case 'view label':
      case 'view':
        return AccessResult::allowedIfHasPermissions($account, ['view connection role entities']);

      case 'create':
      case 'update':
      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['administer connection role entities']);
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermissions($account, ['administer connection role entities']);
  }

}
