<?php

namespace Drupal\redhen_org\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Link;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;


/**
 * Class OrgAddController.
 *
 * @package Drupal\redhen_org\Controller
 */
class OrgAddController extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entity_type_manager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->entity_type_manager = $container->get('entity_type.manager');
    return $instance;
  }

  /**
   * Displays add links for available bundles/types for entity redhen_org .
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request object.
   *
   * @return array
   *   A render array for a list of the redhen_org bundles/types that can be added or
   *   if there is only one type/bunlde defined for the site, the function returns the add page for that bundle/type.
   */
  public function add(Request $request) {
    $types = $this->entity_type_manager->getStorage('redhen_org_type')->loadMultiple();
    if ($types && count($types) == 1) {
      $type = reset($types);
      return $this->addForm($type, $request);
    }
    if (count($types) === 0) {
      return [
        '#markup' => $this->t('You have not created any %bundle types yet. @link to add a new type.', [
          '%bundle' => 'Org',
          '@link' => Link::createFromRoute($this->t('Go to the type creation page'), 'entity.redhen_org_type.add_form')->toString(),
        ]),
      ];
    }
    return ['#theme' => 'redhen_org_content_add_list', '#content' => $types];
  }

  /**
   * Presents the creation form for redhen_org entities of given bundle/type.
   *
   * @param \Drupal\Core\Entity\EntityInterface $redhen_org_type
   *   The custom bundle to add.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request object.
   *
   * @return array
   *   A form array as expected by drupal_render().
   */
  public function addForm(EntityInterface $redhen_org_type, Request $request) {
    $entity = $this->entity_type_manager->getStorage('redhen_org')->create([
      'type' => $redhen_org_type->id(),
    ]);
    return $this->entityFormBuilder()->getForm($entity);
  }

  /**
   * Provides the page title for this controller.
   *
   * @param \Drupal\Core\Entity\EntityInterface $redhen_org_type
   *   The custom bundle/type being added.
   *
   * @return string
   *   The page title.
   */
  public function getAddFormTitle(EntityInterface $redhen_org_type) {
    return t('Create of bundle @label',
      ['@label' => $redhen_org_type->label()]
    );
  }

}
